from pcf8574_io import PCF85


class PCF:

    def __init__(self, address, status):
        self.address = address
        self.status = status
        self.pinModeFlag = 0x00
        self.smBusNum = 1
        PCF85.setup(address, self.smBusNum, status)

    def pin_mode(self, PinName, Mode):
        self.pinModeFlag = PCF85.pin_mode(PinName, Mode, self.pinModeFlag)

    def digital_read(self, PinName):
        return PCF85.digitalRead(PinName, self.smBusNum, self.address)

    def digital_write(self, PinName, Val):
        PCF85.digitalWrite(PinName, Val, self.address, self.pinModeFlag, self.smBusNum)



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Education',
    'Operating System :: Other OS',
    'Topic :: System :: Hardware :: Hardware Drivers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='pcf8574_io',
    version='0.0.5',
    description=' PCF8574 driver to set pin mode, read and write digital signal 3.3v ',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='https://github.com/ahmed9378/pcf8574_io',
    author='Ahmed Omar',
    author_email='ahmed.bm78@gmail.com',
    license='MIT',
    classifiers=classifiers,
    keywords='PCF8574',
    packages=find_packages(),
    install_requires=['smbus2']
)